This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Re: [commit] multi-arch builtin-types #2 of N, language.h


One correction: primative_type_vector: It's spelled "primitive".

Fixed with the attached, thanks.


Andrew

2004-07-28  Andrew Cagney  <cagney@gnu.org>

	* language.h (struct language_arch_info): Fix typo
	s/primative/primitive/.
	* gdbtypes.c (lookup_primitive_typename): Ditto.
	* language.c (language_lookup_primitive_type_by_name)
	(unknown_language_arch_info): Ditto.

Index: gdbtypes.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbtypes.c,v
retrieving revision 1.85
diff -p -u -r1.85 gdbtypes.c
--- gdbtypes.c	28 Jul 2004 02:46:22 -0000	1.85
+++ gdbtypes.c	28 Jul 2004 04:32:45 -0000
@@ -1036,7 +1036,7 @@ type_name_no_tag (const struct type *typ
 struct type *
 lookup_primitive_typename (char *name)
 {
-  return language_lookup_primative_type_by_name (current_language,
+  return language_lookup_primitive_type_by_name (current_language,
 						 current_gdbarch,
 						 name);
 }
Index: language.c
===================================================================
RCS file: /cvs/src/src/gdb/language.c,v
retrieving revision 1.47
diff -p -u -r1.47 language.c
--- language.c	28 Jul 2004 02:46:23 -0000	1.47
+++ language.c	28 Jul 2004 04:32:46 -0000
@@ -1283,7 +1283,7 @@ unknown_language_arch_info (struct gdbar
 			    struct language_arch_info *lai)
 {
   lai->string_char_type = builtin_type (gdbarch)->builtin_char;
-  lai->primative_type_vector = GDBARCH_OBSTACK_CALLOC (gdbarch, 1,
+  lai->primitive_type_vector = GDBARCH_OBSTACK_CALLOC (gdbarch, 1,
 						       struct type *);
 }
 
@@ -1443,16 +1443,16 @@ language_string_char_type (const struct 
 }
 
 struct type *
-language_lookup_primative_type_by_name (const struct language_defn *la,
+language_lookup_primitive_type_by_name (const struct language_defn *la,
 					struct gdbarch *gdbarch,
 					const char *name)
 {
   struct language_gdbarch *ld = gdbarch_data (gdbarch,
 					      language_gdbarch_data);
-  if (ld->arch_info[la->la_language].primative_type_vector != NULL)
+  if (ld->arch_info[la->la_language].primitive_type_vector != NULL)
     {
       struct type *const *p;
-      for (p = ld->arch_info[la->la_language].primative_type_vector;
+      for (p = ld->arch_info[la->la_language].primitive_type_vector;
 	   (*p) != NULL;
 	   p++)
 	{
Index: language.h
===================================================================
RCS file: /cvs/src/src/gdb/language.h,v
retrieving revision 1.28
diff -p -u -r1.28 language.h
--- language.h	28 Jul 2004 02:46:23 -0000	1.28
+++ language.h	28 Jul 2004 04:32:46 -0000
@@ -141,11 +141,11 @@ struct language_format_info
 
 struct language_arch_info
 {
   /* Its primative types.  This is a vector ended by a NULL pointer.
      These types can be specified by name in parsing types in
      expressions, regardless of whether the program being debugged
      actually defines such a type.  */
-  struct type **primative_type_vector;
+  struct type **primitive_type_vector;
   /* Type of elements of strings. */
   struct type *string_char_type;
 };
@@ -153,7 +153,7 @@ struct language_arch_info
 struct type *language_string_char_type (const struct language_defn *l,
 					struct gdbarch *gdbarch);
 
-struct type *language_lookup_primative_type_by_name (const struct language_defn *l,
+struct type *language_lookup_primitive_type_by_name (const struct language_defn *l,
 						     struct gdbarch *gdbarch,
 						     const char *name);
 
@@ -141,11 +141,11 @@ struct language_format_info
 struct language_arch_info
 {
-  /* Its primative types.  This is a vector ended by a NULL pointer.
+  /* Its primitive types.  This is a vector ended by a NULL pointer.
      These types can be specified by name in parsing types in
      expressions, regardless of whether the program being debugged

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]